# Pararead: parallel processing of sequencing reads

[![Build Status](https://travis-ci.org/databio/pypiper.svg?branch=master)](https://travis-ci.org/databio/pararead)

A python package that simplifies parallel processing of DNA sequencing reads (BAM or SAM files), by parallelizing across chromosomes. The best place to learn more is at the [documentation](http://code.databio.org/pararead/).
